@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2012-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef WEECHAT_EVAL_H
@@ -28,6 +28,8 @@
 #define EVAL_DEFAULT_PREFIX "${"
 #define EVAL_DEFAULT_SUFFIX "}"
 
+#define EVAL_RECURSION_MAX  32
+
 struct t_hashtable;
 
 enum t_eval_logical_op
@@ -42,8 +44,14 @@ enum t_eval_comparison
 {
     EVAL_COMPARE_REGEX_MATCHING = 0,
     EVAL_COMPARE_REGEX_NOT_MATCHING,
+    EVAL_COMPARE_STRING_MATCHING_CASE_SENSITIVE,
+    EVAL_COMPARE_STRING_NOT_MATCHING_CASE_SENSITIVE,
     EVAL_COMPARE_STRING_MATCHING,
     EVAL_COMPARE_STRING_NOT_MATCHING,
+    EVAL_COMPARE_INCLUDE_CASE_SENSITIVE,
+    EVAL_COMPARE_NOT_INCLUDE_CASE_SENSITIVE,
+    EVAL_COMPARE_INCLUDE,
+    EVAL_COMPARE_NOT_INCLUDE,
     EVAL_COMPARE_EQUAL,
     EVAL_COMPARE_NOT_EQUAL,
     EVAL_COMPARE_LESS_EQUAL,
@@ -61,6 +69,21 @@ struct t_eval_regex
     int last_match;
 };
 
+struct t_eval_context
+{
+    struct t_hashtable *pointers;      /* pointers used in eval             */
+    struct t_hashtable *extra_vars;    /* extra variables used in eval      */
+    int extra_vars_eval;               /* 1 if extra vars must be evaluated */
+    const char *prefix;                /* prefix (default is "${")          */
+    const char *suffix;                /* suffix (default is "}")           */
+    struct t_eval_regex *regex;        /* in case of replace with regex     */
+    int recursion_count;               /* to prevent infinite recursion     */
+    int debug_level;                   /* 0: no debug, 1: debug, 2: extra   */
+    int debug_depth;                   /* used for debug indentation        */
+    int debug_id;                      /* operation id in debug output      */
+    char **debug_output;               /* string with debug output          */
+};
+
 extern int eval_is_true (const char *value);
 extern char *eval_expression (const char *expr,
                               struct t_hashtable *pointers,
