@@ -1,7 +1,7 @@
 /*
  * wee-hashtable.c - implementation of hashtable
  *
- * Copyright (C) 2010-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2010-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -24,6 +24,7 @@
 #endif
 
 #include <stdlib.h>
+#include <stdint.h>
 #include <string.h>
 #include <time.h>
 
@@ -75,7 +76,7 @@ hashtable_get_type (const char *type)
 unsigned long long
 hashtable_hash_key_djb2 (const char *string)
 {
-    unsigned long long hash;
+    uint64_t hash;
     const char *ptr_string;
 
     hash = 5381;
@@ -549,7 +550,7 @@ hashtable_to_string (enum t_hashtable_type type, const void *value)
         case HASHTABLE_POINTER:
         case HASHTABLE_BUFFER:
             snprintf (str_value, sizeof (str_value),
-                      "0x%lx", (long unsigned int)value);
+                      "0x%lx", (unsigned long)value);
             return str_value;
             break;
         case HASHTABLE_TIME:
@@ -1101,6 +1102,91 @@ hashtable_add_to_infolist (struct t_hashtable *hashtable,
     return 1;
 }
 
+/*
+ * Adds hashtable keys and values from an infolist.
+ *
+ * Returns:
+ *   1: OK
+ *   0: error
+ */
+
+int
+hashtable_add_from_infolist (struct t_hashtable *hashtable,
+                             struct t_infolist *infolist,
+                             const char *prefix)
+{
+    struct t_infolist_var *ptr_name, *ptr_value;
+    char prefix_name[128], option_value[128];
+    int prefix_length;
+
+    if (!hashtable || !infolist || !infolist->ptr_item || !prefix)
+        return 0;
+
+    /* TODO: implement other key types */
+    if (hashtable->type_keys != HASHTABLE_STRING)
+        return 0;
+
+    snprintf (prefix_name, sizeof (prefix_name), "%s_name_", prefix);
+    prefix_length = strlen (prefix_name);
+
+    for (ptr_name = infolist->ptr_item->vars; ptr_name;
+         ptr_name = ptr_name->next_var)
+    {
+        if (string_strncasecmp (ptr_name->name, prefix_name,
+                                prefix_length) == 0)
+        {
+            snprintf (option_value, sizeof (option_value),
+                      "%s_value_%s", prefix, ptr_name->name + prefix_length);
+
+            ptr_value = infolist_search_var (infolist, option_value);
+            if (ptr_value)
+            {
+                switch (hashtable->type_values)
+                {
+                    case HASHTABLE_INTEGER:
+                        if (ptr_value->type != INFOLIST_INTEGER)
+                            return 0;
+                        break;
+                    case HASHTABLE_STRING:
+                        if (ptr_value->type != INFOLIST_STRING)
+                            return 0;
+                        break;
+                    case HASHTABLE_POINTER:
+                        if (ptr_value->type != INFOLIST_POINTER)
+                            return 0;
+                        break;
+                    case HASHTABLE_BUFFER:
+                        if (ptr_value->type != INFOLIST_BUFFER)
+                            return 0;
+                        break;
+                    case HASHTABLE_TIME:
+                        if (ptr_value->type != INFOLIST_TIME)
+                            return 0;
+                        break;
+                    case HASHTABLE_NUM_TYPES:
+                        break;
+                }
+                if (hashtable->type_values == HASHTABLE_BUFFER)
+                {
+                    hashtable_set_with_size (hashtable,
+                                             ptr_name->value,
+                                             0,
+                                             ptr_value->value,
+                                             ptr_value->size);
+                }
+                else
+                {
+                    hashtable_set (hashtable,
+                                   ptr_name->value,
+                                   ptr_value->value);
+                }
+            }
+        }
+    }
+
+    return 1;
+}
+
 /*
  * Removes an item from hashtable.
  */
@@ -1256,7 +1342,7 @@ hashtable_print_log (struct t_hashtable *hashtable, const char *name)
                     log_printf ("      value (buffer) . . : 0x%lx", ptr_item->value);
                     break;
                 case HASHTABLE_TIME:
-                    log_printf ("      value (time) . . . : %d", *((time_t *)ptr_item->value));
+                    log_printf ("      value (time) . . . : %lld", (long long)(*((time_t *)ptr_item->value)));
                     break;
                 case HASHTABLE_NUM_TYPES:
                     break;
