@@ -1,7 +1,7 @@
 /*
  * alias-config.c - alias configuration options (file alias.conf)
  *
- * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <stdlib.h>
@@ -33,8 +33,6 @@ struct t_config_section *alias_config_section_completion = NULL;
 
 char *alias_default[][3] =
 { { "AAWAY",   "allserv /away",        NULL            },
-  { "AME",     "allchan /me",          NULL            },
-  { "AMSG",    "allchan /msg *",       NULL            },
   { "ANICK",   "allserv /nick",        NULL            },
   { "BEEP",    "print -beep",          NULL            },
   { "BYE",     "quit",                 NULL            },
@@ -62,9 +60,10 @@ char *alias_default[][3] =
   { "UMODE",   "mode $nick",           NULL            },
   { "V",       "command core version", NULL            },
   { "W",       "who",                  NULL            },
-  { "WC",      "window merge",         NULL            },
+  { "WC",      "window close",         NULL            },
   { "WI",      "whois",                NULL            },
   { "WII",     "whois $1 $1",          NULL            },
+  { "WM",      "window merge",         NULL            },
   { "WW",      "whowas",               NULL            },
   { NULL,      NULL,                   NULL            },
 };
@@ -386,6 +385,7 @@ alias_config_init ()
     if (!ptr_section)
     {
         weechat_config_free (alias_config_file);
+        alias_config_file = NULL;
         return 0;
     }
     alias_config_section_cmd = ptr_section;
@@ -402,6 +402,7 @@ alias_config_init ()
     if (!ptr_section)
     {
         weechat_config_free (alias_config_file);
+        alias_config_file = NULL;
         return 0;
     }
     alias_config_section_completion = ptr_section;
