@@ -193,6 +193,10 @@ struct t_irc_server
     struct t_hook *hook_fd;         /* hook for server socket                */
     struct t_hook *hook_timer_connection; /* timer for connection            */
     struct t_hook *hook_timer_sasl; /* timer for SASL authentication         */
+    char *sasl_scram_client_first;  /* first message sent for SASL SCRAM     */
+    char *sasl_scram_salted_pwd;    /* salted password for SASL SCRAM        */
+    int sasl_scram_salted_pwd_size; /* size of salted password for SASL SCRAM*/
+    char *sasl_scram_auth_message;  /* auth message for SASL SCRAM           */
     int is_connected;               /* 1 if WeeChat is connected to server   */
     int ssl_connected;              /* = 1 if connected with SSL             */
     int disconnected;               /* 1 if server has been disconnected     */
@@ -323,6 +327,7 @@ extern const char *irc_server_get_chantypes (struct t_irc_server *server);
 extern void irc_server_set_prefix_modes_chars (struct t_irc_server *server,
                                                const char *prefix);
 extern void irc_server_set_lag (struct t_irc_server *server);
+extern void irc_server_set_tls_version (struct t_irc_server *server);
 extern const char *irc_server_get_prefix_modes (struct t_irc_server *server);
 extern const char *irc_server_get_prefix_chars (struct t_irc_server *server);
 extern int irc_server_get_prefix_mode_index (struct t_irc_server *server,
@@ -339,7 +344,8 @@ extern int irc_server_prefix_char_statusmsg (struct t_irc_server *server,
 extern int irc_server_get_max_modes (struct t_irc_server *server);
 extern char *irc_server_get_default_msg (const char *default_msg,
                                          struct t_irc_server *server,
-                                         const char *channel_name);
+                                         const char *channel_name,
+                                         const char *target_nick);
 extern struct t_irc_server *irc_server_alloc (const char *name);
 extern struct t_irc_server *irc_server_alloc_with_url (const char *irc_url);
 extern void irc_server_apply_command_line_options (struct t_irc_server *server,
@@ -386,6 +392,7 @@ extern void irc_server_switch_address (struct t_irc_server *server,
 extern void irc_server_disconnect (struct t_irc_server *server,
                                    int switch_address, int reconnect);
 extern void irc_server_disconnect_all ();
+extern void irc_server_free_sasl_data (struct t_irc_server *server);
 extern void irc_server_free (struct t_irc_server *server);
 extern int irc_server_xfer_send_ready_cb (const void *pointer, void *data,
                                           const char *signal,
