@@ -38,6 +38,7 @@
 #include "../core/weechat.h"
 #include "../core/wee-arraylist.h"
 #include "../core/wee-config.h"
+#include "../core/wee-dir.h"
 #include "../core/wee-eval.h"
 #include "../core/wee-hashtable.h"
 #include "../core/wee-hdata.h"
@@ -664,12 +665,13 @@ plugin_load (const char *filename, int init_plugin, int argc, char **argv)
 
         new_plugin->crypto_hash = &plugin_api_crypto_hash;
         new_plugin->crypto_hash_pbkdf2 = &plugin_api_crypto_hash_pbkdf2;
+        new_plugin->crypto_hmac = &plugin_api_crypto_hmac;
 
-        new_plugin->mkdir_home = &util_mkdir_home;
-        new_plugin->mkdir = &util_mkdir;
-        new_plugin->mkdir_parents = &util_mkdir_parents;
-        new_plugin->exec_on_files = &util_exec_on_files;
-        new_plugin->file_get_content = &util_file_get_content;
+        new_plugin->mkdir_home = &dir_mkdir_home;
+        new_plugin->mkdir = &dir_mkdir;
+        new_plugin->mkdir_parents = &dir_mkdir_parents;
+        new_plugin->exec_on_files = &dir_exec_on_files;
+        new_plugin->file_get_content = &dir_file_get_content;
 
         new_plugin->util_timeval_cmp = &util_timeval_cmp;
         new_plugin->util_timeval_diff = &util_timeval_diff;
@@ -1011,11 +1013,12 @@ plugin_auto_load (char *force_plugin_autoload,
                   int load_from_lib_dir,
                   int argc, char **argv)
 {
-    char *dir_name, *plugin_path, *plugin_path2, *extra_libdir;
+    char *dir_name, *plugin_path, *extra_libdir;
     const char *ptr_plugin_autoload;
     struct t_weechat_plugin *ptr_plugin;
     struct t_plugin_args plugin_args;
     struct t_arraylist *arraylist;
+    struct t_hashtable *options;
     int length, i;
 
     plugin_args.argc = argc;
@@ -1045,20 +1048,23 @@ plugin_auto_load (char *force_plugin_autoload,
         && CONFIG_STRING(config_plugin_path)
         && CONFIG_STRING(config_plugin_path)[0])
     {
-        plugin_path = string_expand_home (CONFIG_STRING(config_plugin_path));
-        plugin_path2 = string_replace ((plugin_path) ?
-                                       plugin_path : CONFIG_STRING(config_plugin_path),
-                                       "%h", weechat_home);
-        util_exec_on_files ((plugin_path2) ?
-                            plugin_path2 : ((plugin_path) ?
-                                            plugin_path : CONFIG_STRING(config_plugin_path)),
-                            1,
-                            0,
-                            &plugin_auto_load_file, &plugin_args);
+        options = hashtable_new (
+            32,
+            WEECHAT_HASHTABLE_STRING,
+            WEECHAT_HASHTABLE_STRING,
+            NULL, NULL);
+        if (options)
+            hashtable_set (options, "directory", "data");
+        plugin_path = string_eval_path_home (CONFIG_STRING(config_plugin_path),
+                                             NULL, NULL, options);
+        if (options)
+            hashtable_free (options);
         if (plugin_path)
+        {
+            dir_exec_on_files (plugin_path, 1, 0,
+                               &plugin_auto_load_file, &plugin_args);
             free (plugin_path);
-        if (plugin_path2)
-            free (plugin_path2);
+        }
     }
 
     /* auto-load plugins in WEECHAT_EXTRA_LIBDIR environment variable */
@@ -1070,8 +1076,8 @@ plugin_auto_load (char *force_plugin_autoload,
             length = strlen (extra_libdir) + 16 + 1;
             dir_name = malloc (length);
             snprintf (dir_name, length, "%s/plugins", extra_libdir);
-            util_exec_on_files (dir_name, 1, 0,
-                                &plugin_auto_load_file, &plugin_args);
+            dir_exec_on_files (dir_name, 1, 0,
+                               &plugin_auto_load_file, &plugin_args);
             free (dir_name);
         }
     }
@@ -1084,8 +1090,8 @@ plugin_auto_load (char *force_plugin_autoload,
         if (dir_name)
         {
             snprintf (dir_name, length, "%s/plugins", WEECHAT_LIBDIR);
-            util_exec_on_files (dir_name, 1, 0,
-                                &plugin_auto_load_file, &plugin_args);
+            dir_exec_on_files (dir_name, 1, 0,
+                               &plugin_auto_load_file, &plugin_args);
             free (dir_name);
         }
     }
