@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,13 +14,14 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef WEECHAT_PLUGIN_RELAY_IRC_H
 #define WEECHAT_PLUGIN_RELAY_IRC_H
 
 struct t_relay_client;
+enum t_relay_status;
 
 #define RELAY_IRC_DATA(client, var)                              \
     (((struct t_relay_irc_data *)client->protocol_data)->var)
@@ -69,6 +70,7 @@ extern void relay_irc_close_connection (struct t_relay_client *client);
 extern void relay_irc_alloc (struct t_relay_client *client);
 extern void relay_irc_alloc_with_infolist (struct t_relay_client *client,
                                            struct t_infolist *infolist);
+extern enum t_relay_status relay_irc_get_initial_status (struct t_relay_client *client);
 extern void relay_irc_free (struct t_relay_client *client);
 extern int relay_irc_add_to_infolist (struct t_infolist_item *item,
                                       struct t_relay_client *client);
